@@ -27,7 +27,7 @@ class HomeAssistantCog(commands.Cog):
     async def vacuum(self, context: discord.Interaction, choices: str):
         roomba = ha.Vacuum()
         status = getattr(roomba, choices)()
-        await context.response.send_message(f"Vacuum is {status or choices}ing")
+        await context.response.send_message(f"Vacuum is {status or choices}")
 
     @app_commands.command(name="alarm")
     @app_commands.choices(choices=get_functions(ha.Alarm))
@@ -35,7 +35,7 @@ class HomeAssistantCog(commands.Cog):
     async def arm(self, context: discord.Interaction, choices: str):
         alarm = ha.Alarm()
         status = getattr(alarm, choices)()
-        await context.response.send_message(f"Alarm is {status or choices}ing")
+        await context.response.send_message(f"Alarm is {status or choices}")
 
     @app_commands.command(name="taylor_swiftly")
     @app_commands.choices(choices=get_functions(ha.TaylorSwiftly()))
@@ -43,7 +43,7 @@ class HomeAssistantCog(commands.Cog):
     async def tesla(self, context: discord.Interaction, choices: str):
         taylor = ha.TaylorSwiftly()
         status = taylor.get_functions()[choices]()
-        await context.response.send_message(f"Taylor Swiftly {choices.split()[1]} is {status}")
+        await context.response.send_message(f"Taylor Swiftly {choices.split()[1]} is {status or choices}")
 
     @app_commands.errors.MissingRole
     async def on_command_error(self, context, error):
