@@ -116,12 +116,24 @@ class Sensor(HomeAssistant):
         super().__init__(*args, **kwargs)
 
 
+class Button(HomeAssistant):
+    def __init__(self, *args, **kwargs):
+        self.domain = "button"
+        super().__init__(*args, **kwargs)
+
+    def start(self) -> str:
+        """Start button"""
+        self.client.get_domain(self.domain).press(entity_id=self.entity_id)
+        return "starting"
+
+
 class TaylorSwiftly:
     """Class for Taylor Swiftly Lock"""
 
     def __init__(self):
         self.battery = Sensor("taylor_swiftly_battery", location="home")
         self.lock = Lock("taylor_swiftly_doors", location="home")
+        self.start = Button("taylor_swiftly_remote_start", location="home")
 
     def get_functions(self):
         """Return functions"""
